====
xpaw
====

.. image:: https://img.shields.io/badge/license-Apache 2-blue.svg
    :target: https://github.com/jadbin/xpaw/blob/master/LICENSE


Overview
========

xpaw is a web scraping framework, used to crawl web pages and extract structured data from them.

Documentation: http://xpaw.readthedocs.org/en/latest/


Requirements
============

- Python >= 3.5
- `aiohttp`_
- `pyyaml`_
- `lxml`_

.. _aiohttp: https://pypi.python.org/pypi/aiohttp
.. _pyyaml: https://pypi.python.org/pypi/pyyaml
.. _lxml: https://pypi.python.org/pypi/lxml
